<p class="home">
 <h1><a href="{{ pathto(master_doc) }}">
    Flask-Marshmallow Home</a></h1>
</p>

<p>
  <iframe src="http://ghbtns.com/github-btn.html?user=marshmallow-code&repo=flask-marshmallow&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="200px" height="35px"></iframe>
</p>

<p>
Flask + marshmallow for beautiful APIs
</p>

<h3>Useful Links</h3>
<ul>
  <li><a href="http://pypi.python.org/pypi/flask-marshmallow">Flask-Marshmallow @ PyPI</a></li>
  <li><a href="http://github.com/marshmallow-code/flask-marshmallow">Flask-Marshmallow @ GitHub</a></li>
  <li><a href="http://github.com/marshmallow-code/flask-marshmallow/issues">Issue Tracker</a></li>
</ul>

<h3>Stay Informed</h3>

<p><iframe src="http://ghbtns.com/github-btn.html?user=marshmallow-code&type=follow"
  allowtransparency="true" frameborder="0" scrolling="0" width="165" height="20"></iframe></p>
